@@ -1,6 +1,6 @@
 /*
 Copyright (c) 2008-2010
-	Lars-Dominik Braun <PromyLOPh@lavabit.com>
+	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -56,7 +56,7 @@ THE SOFTWARE.
  *	@param apply this gain
  *	@return this * yourvalue = newgain value
  */
-static inline unsigned int computeReplayGainScale (float applyGain) {
+unsigned int BarPlayerCalcScale (float applyGain) {
 	return pow (10.0, applyGain / 20.0) * RG_SCALE_FACTOR;
 }
 
@@ -199,7 +199,7 @@ static WaitressCbReturn_t BarPlayerAACCb (void *ptr, size_t size, void *stream)
 					format.bits = 16;
 					format.channels = player->channels;
 					format.rate = player->samplerate;
-					format.byte_format = AO_FMT_LITTLE;
+					format.byte_format = AO_FMT_NATIVE;
 					if ((player->audioOutDevice = ao_open_live (audioOutDriver,
 							&format, NULL)) == NULL) {
 						/* we're not interested in the errno */
@@ -358,7 +358,7 @@ static WaitressCbReturn_t BarPlayerMp3Cb (void *ptr, size_t size, void *stream)
 			format.bits = 16;
 			format.channels = player->channels;
 			format.rate = player->samplerate;
-			format.byte_format = AO_FMT_LITTLE;
+			format.byte_format = AO_FMT_NATIVE;
 			if ((player->audioOutDevice = ao_open_live (audioOutDriver,
 					&format, NULL)) == NULL) {
 				player->aoError = 1;
@@ -414,7 +414,6 @@ void *BarPlayerThread (void *data) {
 
 	/* init handles */
 	pthread_mutex_init (&player->pauseMutex, NULL);
-	player->scale = computeReplayGainScale (player->gain);
 	player->waith.data = (void *) player;
 	/* extraHeaders will be initialized later */
 	player->waith.extraHeaders = extraHeaders;
