@@ -1,6 +1,6 @@
 /*
 Copyright (c) 2008-2010
-	Lars-Dominik Braun <PromyLOPh@lavabit.com>
+	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -102,5 +102,6 @@ struct audioPlayer {
 enum {PLAYER_RET_OK = 0, PLAYER_RET_ERR = 1};
 
 void *BarPlayerThread (void *data);
+unsigned int BarPlayerCalcScale (float);
 
 #endif /* _PLAYER_H */
