@@ -1,6 +1,6 @@
 /*
 Copyright (c) 2008-2010
-	Lars-Dominik Braun <PromyLOPh@lavabit.com>
+	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -23,15 +23,19 @@ THE SOFTWARE.
 
 /* application settings */
 
+#define _POSIX_C_SOURCE 1 /* PATH_MAX */
 #define _BSD_SOURCE /* strdup() */
 
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <limits.h>
 
 #include "settings.h"
 #include "config.h"
 
+#define streq(a, b) (strcmp (a, b) == 0)
+
 /*	tries to guess your config dir; somehow conforming to
  *	http://standards.freedesktop.org/basedir-spec/basedir-spec-0.6.html
  *	@param name of the config file (can contain subdirs too)
@@ -77,6 +81,8 @@ void BarSettingsDestroy (BarSettings_t *settings) {
 	free (settings->password);
 	free (settings->autostartStation);
 	free (settings->eventCmd);
+	free (settings->loveIcon);
+	free (settings->banIcon);
 	memset (settings, 0, sizeof (*settings));
 }
 
@@ -85,13 +91,12 @@ void BarSettingsDestroy (BarSettings_t *settings) {
  *	@return nothing yet
  */
 void BarSettingsRead (BarSettings_t *settings) {
-	/* FIXME: what is the max length of a path? */
-	char configfile[1024], key[256], val[256];
+	char configfile[PATH_MAX], key[256], val[256];
 	FILE *configfd;
 	/* _must_ have same order as in BarKeyShortcutId_t */
 	static const char defaultKeys[] = {'?', '+', '-', 'a', 'c', 'd', 'e', 'g',
 			'h', 'i', 'j', 'm', 'n', 'p', 'q', 'r', 's', 't', 'u', 'x', '$',
-			'b',
+			'b', '(', ')',
 			};
 	static const char *shortcutFileKeys[] = {
 			"act_help", "act_songlove", "act_songban", "act_stationaddmusic",
@@ -100,7 +105,7 @@ void BarSettingsRead (BarSettings_t *settings) {
 			"act_addshared", "act_songmove", "act_songnext", "act_songpause",
 			"act_quit", "act_stationrename", "act_stationchange",
 			"act_songtired", "act_upcoming", "act_stationselectquickmix",
-			"act_debug", "act_bookmark",
+			"act_debug", "act_bookmark", "act_voldown", "act_volup",
 			};
 
 	/* apply defaults */
@@ -112,8 +117,11 @@ void BarSettingsRead (BarSettings_t *settings) {
 		#endif
 	#endif
 	settings->history = 5;
+	settings->volume = 0;
 	settings->sortOrder = BAR_SORT_NAME_AZ;
 	memcpy (settings->keys, defaultKeys, sizeof (defaultKeys));
+	settings->loveIcon = strdup ("<3");
+	settings->banIcon = strdup ("</3");
 
 	BarGetXdgConfigDir (PACKAGE "/config", configfile, sizeof (configfile));
 	if ((configfd = fopen (configfile, "r")) == NULL) {
@@ -129,38 +137,38 @@ void BarSettingsRead (BarSettings_t *settings) {
 			/* invalid config line */
 			continue;
 		}
-		if (strcmp ("control_proxy", key) == 0) {
+		if (streq ("control_proxy", key)) {
 			settings->controlProxy = strdup (val);
-		} else if (strcmp ("proxy", key) == 0) {
+		} else if (streq ("proxy", key)) {
 			settings->proxy = strdup (val);
-		} else if (strcmp ("user", key) == 0) {
+		} else if (streq ("user", key)) {
 			settings->username = strdup (val);
-		} else if (strcmp ("password", key) == 0) {
+		} else if (streq ("password", key)) {
 			settings->password = strdup (val);
 		} else if (memcmp ("act_", key, 4) == 0) {
 			size_t i;
 			/* keyboard shortcuts */
 			for (i = 0; i < BAR_KS_COUNT; i++) {
-				if (strcmp (shortcutFileKeys[i], key) == 0) {
+				if (streq (shortcutFileKeys[i], key)) {
 					settings->keys[i] = val[0];
 					break;
 				}
 			}
-		} else if (strcmp ("audio_format", key) == 0) {
-			if (strcmp (val, "aacplus") == 0) {
+		} else if (streq ("audio_format", key)) {
+			if (streq (val, "aacplus")) {
 				settings->audioFormat = PIANO_AF_AACPLUS;
-			} else if (strcmp (val, "mp3") == 0) {
+			} else if (streq (val, "mp3")) {
 				settings->audioFormat = PIANO_AF_MP3;
-			} else if (strcmp (val, "mp3-hifi") == 0) {
+			} else if (streq (val, "mp3-hifi")) {
 				settings->audioFormat = PIANO_AF_MP3_HI;
 			}
-		} else if (strcmp ("autostart_station", key) == 0) {
+		} else if (streq ("autostart_station", key)) {
 			settings->autostartStation = strdup (val);
-		} else if (strcmp ("event_command", key) == 0) {
+		} else if (streq ("event_command", key)) {
 			settings->eventCmd = strdup (val);
-		} else if (strcmp ("history", key) == 0) {
+		} else if (streq ("history", key)) {
 			settings->history = atoi (val);
-		} else if (strcmp ("sort", key) == 0) {
+		} else if (streq ("sort", key)) {
 			size_t i;
 			static const char *mapping[] = {"name_az",
 					"name_za",
@@ -170,11 +178,19 @@ void BarSettingsRead (BarSettings_t *settings) {
 					"quickmix_10_name_za",
 					};
 			for (i = 0; i < BAR_SORT_COUNT; i++) {
-				if (strcmp (mapping[i], val) == 0) {
+				if (streq (mapping[i], val)) {
 					settings->sortOrder = i;
 					break;
 				}
 			}
+		} else if (streq ("love_icon", key)) {
+			free (settings->loveIcon);
+			settings->loveIcon = strdup (val);
+		} else if (streq ("ban_icon", key)) {
+			free (settings->banIcon);
+			settings->banIcon = strdup (val);
+		} else if (streq ("volume", key)) {
+			settings->volume = atoi (val);
 		}
 	}
 
