@@ -1,6 +1,6 @@
 /*
 Copyright (c) 2008-2010
-	Lars-Dominik Braun <PromyLOPh@lavabit.com>
+	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -52,8 +52,10 @@ typedef enum {
 	BAR_KS_SELECTQUICKMIX = 19,
 	BAR_KS_DEBUG = 20,
 	BAR_KS_BOOKMARK = 21,
+	BAR_KS_VOLDOWN = 22,
+	BAR_KS_VOLUP = 23,
 	/* insert new shortcuts _before_ this element and increase its value */
-	BAR_KS_COUNT = 22,
+	BAR_KS_COUNT = 24,
 } BarKeyShortcutId_t;
 
 typedef enum {
@@ -68,6 +70,7 @@ typedef enum {
 
 typedef struct {
 	unsigned int history;
+	int volume;
 	BarStationSorting_t sortOrder;
 	PianoAudioFormat_t audioFormat;
 	char *username;
@@ -77,6 +80,8 @@ typedef struct {
 	char keys[BAR_KS_COUNT];
 	char *autostartStation;
 	char *eventCmd;
+	char *loveIcon;
+	char *banIcon;
 } BarSettings_t;
 
 void BarSettingsInit (BarSettings_t *);
