@@ -1,6 +1,6 @@
 /*
 Copyright (c) 2008-2010
-	Lars-Dominik Braun <PromyLOPh@lavabit.com>
+	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -48,31 +48,32 @@ typedef int (*BarSortFunc_t) (const void *, const void *);
  *	@param message
  */
 inline void BarUiMsg (uiMsg_t type, const char *format, ...) {
+	#define ANSI_CLEAR_LINE "\033[2K"
 	va_list fmtargs;
 
 	switch (type) {
 		case MSG_INFO:
-			printf ("(i) ");
+			printf (ANSI_CLEAR_LINE "(i) ");
 			break;
 
 		case MSG_PLAYING:
-			printf ("|>  ");
+			printf (ANSI_CLEAR_LINE "|>  ");
 			break;
 
 		case MSG_TIME:
-			printf ("#   ");
+			printf (ANSI_CLEAR_LINE "#   ");
 			break;
 		
 		case MSG_ERR:
-			printf ("/!\\ ");
+			printf (ANSI_CLEAR_LINE "/!\\ ");
 			break;
 
 		case MSG_QUESTION:
-			printf ("[?] ");
+			printf (ANSI_CLEAR_LINE "[?] ");
 			break;
 
 		case MSG_LIST:
-			printf ("       ");
+			printf (ANSI_CLEAR_LINE "\t");
 			break;
 	
 		default:
@@ -83,6 +84,8 @@ inline void BarUiMsg (uiMsg_t type, const char *format, ...) {
 	va_end (fmtargs);
 
 	fflush (stdout);
+
+	#undef ANSI_CLEAR_LINE
 }
 
 /*	prints human readable status message based on return value
@@ -302,6 +305,11 @@ PianoStation_t *BarUiSelectStation (PianoHandle_t *ph, const char *prompt,
 	size_t stationCount, i;
 	int input;
 
+	if (ph->stations == NULL) {
+		BarUiMsg (MSG_ERR, "No station available.\n");
+		return NULL;
+	}
+
 	/* sort and print stations */
 	sortedStations = BarSortedStations (ph->stations, &stationCount, order);
 	for (i = 0; i < stationCount; i++) {
@@ -327,30 +335,29 @@ PianoStation_t *BarUiSelectStation (PianoHandle_t *ph, const char *prompt,
 }
 
 /*	let user pick one song
+ *	@param pianobar settings
  *	@param song list
+ *	@param current fd
  *	@return pointer to selected item in song list or NULL
  */
-PianoSong_t *BarUiSelectSong (PianoSong_t *startSong, FILE *curFd) {
+PianoSong_t *BarUiSelectSong (const BarSettings_t *settings,
+		PianoSong_t *startSong, FILE *curFd) {
 	PianoSong_t *tmpSong = NULL;
 	int i = 0;
 
-	/* print all songs */
-	tmpSong = startSong;
-	while (tmpSong != NULL) {
-		BarUiMsg (MSG_LIST, "%2u) %s - %s\n", i, tmpSong->artist,
-				tmpSong->title);
-		i++;
-		tmpSong = tmpSong->next;
-	}
+	i = BarUiListSongs (settings, startSong);
+
 	BarUiMsg (MSG_QUESTION, "Select song: ");
 	if (BarReadlineInt (&i, curFd) == 0) {
 		return NULL;
 	}
+
 	tmpSong = startSong;
 	while (tmpSong != NULL && i > 0) {
 		tmpSong = tmpSong->next;
 		i--;
 	}
+
 	return tmpSong;
 }
 
@@ -436,14 +443,16 @@ char *BarUiSelectMusicId (BarApp_t *app, FILE *curFd, char *similarToId) {
 					musicId = strdup (tmpArtist->musicId);
 				}
 			} else if (*selectBuf == 't') {
-				tmpSong = BarUiSelectSong (searchResult.songs, curFd);
+				tmpSong = BarUiSelectSong (&app->settings, searchResult.songs,
+						curFd);
 				if (tmpSong != NULL) {
 					musicId = strdup (tmpSong->musicId);
 				}
 			}
 		} else if (searchResult.songs != NULL) {
 			/* songs found */
-			tmpSong = BarUiSelectSong (searchResult.songs, curFd);
+			tmpSong = BarUiSelectSong (&app->settings, searchResult.songs,
+					curFd);
 			if (tmpSong != NULL) {
 				musicId = strdup (tmpSong->musicId);
 			}
@@ -536,17 +545,41 @@ inline void BarUiPrintStation (PianoStation_t *station) {
 }
 
 /*	Print song infos (artist, title, album, loved)
+ *	@param pianobar settings
  *	@param the song
  *	@param alternative station info (show real station for quickmix, e.g.)
  */
-inline void BarUiPrintSong (PianoSong_t *song, PianoStation_t *station) {
-	BarUiMsg (MSG_PLAYING, "\"%s\" by \"%s\" on \"%s\"%s%s%s\n",
+inline void BarUiPrintSong (const BarSettings_t *settings,
+		const PianoSong_t *song, const PianoStation_t *station) {
+	BarUiMsg (MSG_PLAYING, "\"%s\" by \"%s\" on \"%s\"%s%s%s%s\n",
 			song->title, song->artist, song->album,
-			(song->rating == PIANO_RATE_LOVE) ? " <3" : "",
+			(song->rating == PIANO_RATE_LOVE) ? " " : "",
+			(song->rating == PIANO_RATE_LOVE) ? settings->loveIcon : "",
 			station != NULL ? " @ " : "",
 			station != NULL ? station->name : "");
 }
 
+/*	Print list of songs
+ *	@param pianobar settings
+ *	@param linked list of songs
+ *	@return # of songs
+ */
+size_t BarUiListSongs (const BarSettings_t *settings,
+		const PianoSong_t *song) {
+	size_t i = 0;
+
+	while (song != NULL) {
+		BarUiMsg (MSG_LIST, "%2lu) %s - %s %s%s\n", i, song->artist,
+				song->title,
+				(song->rating == PIANO_RATE_LOVE) ? settings->loveIcon : "",
+				(song->rating == PIANO_RATE_BAN) ? settings->banIcon : "");
+		song = song->next;
+		i++;
+	}
+
+	return i;
+}
+
 /*	Excute external event handler
  *	@param settings containing the cmdline
  *	@param event type
@@ -557,8 +590,8 @@ inline void BarUiPrintSong (PianoSong_t *song, PianoStation_t *station) {
  */
 void BarUiStartEventCmd (const BarSettings_t *settings, const char *type,
 		const PianoStation_t *curStation, const PianoSong_t *curSong,
-		const struct audioPlayer *player, PianoReturn_t pRet,
-		WaitressReturn_t wRet) {
+		const struct audioPlayer *player, PianoStation_t *stations,
+                PianoReturn_t pRet, WaitressReturn_t wRet) {
 	pid_t chld;
 	char pipeBuf[1024];
 	int pipeFd[2];
@@ -574,6 +607,7 @@ void BarUiStartEventCmd (const BarSettings_t *settings, const char *type,
 			"artist=%s\n"
 			"title=%s\n"
 			"album=%s\n"
+			"coverArt=%s\n"
 			"stationName=%s\n"
 			"pRet=%i\n"
 			"pRetStr=%s\n"
@@ -585,6 +619,7 @@ void BarUiStartEventCmd (const BarSettings_t *settings, const char *type,
 			curSong == NULL ? "" : curSong->artist,
 			curSong == NULL ? "" : curSong->title,
 			curSong == NULL ? "" : curSong->album,
+			curSong == NULL ? "" : curSong->coverArt,
 			curStation == NULL ? "" : curStation->name,
 			pRet,
 			PianoErrorToStr (pRet),
@@ -594,7 +629,7 @@ void BarUiStartEventCmd (const BarSettings_t *settings, const char *type,
 			player->songPlayed,
 			curSong == NULL ? PIANO_RATE_NONE : curSong->rating
 			);
-	
+
 	if (pipe (pipeFd) == -1) {
 		BarUiMsg (MSG_ERR, "Cannot create eventcmd pipe. (%s)\n", strerror (errno));
 		return;
@@ -616,6 +651,30 @@ void BarUiStartEventCmd (const BarSettings_t *settings, const char *type,
 		int status;
 		close (pipeFd[0]);
 		write (pipeFd[1], pipeBuf, strlen (pipeBuf));
+
+		if (stations != NULL) {
+			/* send station list */
+			PianoStation_t **sortedStations = NULL;
+			size_t stationCount;
+			sortedStations = BarSortedStations (stations, &stationCount,
+					settings->sortOrder);
+			assert (sortedStations != NULL);
+
+			snprintf (pipeBuf, sizeof (pipeBuf), "stationCount=%zd\n", stationCount);
+			write (pipeFd[1], pipeBuf, strlen (pipeBuf));
+
+			for (size_t i = 0; i < stationCount; i++) {
+				const PianoStation_t *currStation = sortedStations[i];
+				snprintf (pipeBuf, sizeof (pipeBuf), "station%zd=%s\n", i,
+						currStation->name);
+				write (pipeFd[1], pipeBuf, strlen (pipeBuf));
+			}
+			free (sortedStations);
+		} else {
+			const char *msg = "stationCount=0\n";
+			write (pipeFd[1], msg, strlen (msg));
+		}
+	
 		close (pipeFd[1]);
 		/* wait to get rid of the zombie */
 		waitpid (chld, &status, 0);
