@@ -1,6 +1,6 @@
 /*
 Copyright (c) 2008-2010
-	Lars-Dominik Braun <PromyLOPh@lavabit.com>
+	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -42,7 +42,8 @@ THE SOFTWARE.
 /*	standard eventcmd call
  */
 #define BarUiActDefaultEventcmd(name) BarUiStartEventCmd (&app->settings, \
-		name, app->curStation, app->playlist, &app->player, pRet, wRet)
+		name, app->curStation, app->playlist, &app->player, app->ph.stations, \
+		pRet, wRet)
 
 /*	standard piano call
  */
@@ -103,6 +104,8 @@ BarUiActCallback(BarUiActHelp) {
 			"select quickmix stations",
 			NULL,
 			"bookmark song/artist",
+			"decrease volume",
+			"increase volume",
 			};
 	size_t i;
 
@@ -254,7 +257,8 @@ BarUiActCallback(BarUiActSongInfo) {
 
 	BarUiPrintStation (app->curStation);
 	/* print real station if quickmix */
-	BarUiPrintSong (app->playlist, app->curStation->isQuickMix ?
+	BarUiPrintSong (&app->settings, app->playlist,
+			app->curStation->isQuickMix ?
 			PianoFindStationById (app->ph.stations, app->playlist->stationId) :
 			NULL);
 }
@@ -270,6 +274,7 @@ BarUiActCallback(BarUiActDebug) {
 			"artist:\t%s\n"
 			"audioFormat:\t%i\n"
 			"audioUrl:\t%s\n"
+			"coverArt:\t%s\n"
 			"fileGain:\t%f\n"
 			"musicId:\t%s\n"
 			"rating:\t%i\n"
@@ -279,7 +284,9 @@ BarUiActCallback(BarUiActDebug) {
 			"title:\t%s\n"
 			"userSeed:\t%s\n",
 			app->playlist->album, app->playlist->artist,
-			app->playlist->audioFormat, app->playlist->audioUrl,
+			app->playlist->audioFormat,
+			app->playlist->audioUrl,
+			app->playlist->coverArt,
 			app->playlist->fileGain,
 			app->playlist->musicId, app->playlist->rating,
 			app->playlist->songType, app->playlist->stationId,
@@ -420,13 +427,7 @@ BarUiActCallback(BarUiActPrintUpcoming) {
 
 	PianoSong_t *nextSong = app->playlist->next;
 	if (nextSong != NULL) {
-		int i = 0;
-		while (nextSong != NULL) {
-			BarUiMsg (MSG_LIST, "%2i) \"%s\" by \"%s\"\n", i, nextSong->title,
-					nextSong->artist);
-			nextSong = nextSong->next;
-			i++;
-		}
+		BarUiListSongs (&app->settings, nextSong);
 	} else {
 		BarUiMsg (MSG_INFO, "No songs in queue.\n");
 	}
@@ -468,25 +469,29 @@ BarUiActCallback(BarUiActQuit) {
 BarUiActCallback(BarUiActHistory) {
 	PianoReturn_t pRet;
 	WaitressReturn_t wRet;
-	char selectBuf[2], allowedBuf[3];
+	char selectBuf[2], allowedBuf[4];
 	PianoSong_t *selectedSong;
 
 	if (app->songHistory != NULL) {
-		selectedSong = BarUiSelectSong (app->songHistory, curFd);
+		selectedSong = BarUiSelectSong (&app->settings, app->songHistory,
+				curFd);
 		if (selectedSong != NULL) {
 			/* use user-defined keybindings */
 			allowedBuf[0] = app->settings.keys[BAR_KS_LOVE];
 			allowedBuf[1] = app->settings.keys[BAR_KS_BAN];
-			allowedBuf[2] = '\0';
+			allowedBuf[2] = app->settings.keys[BAR_KS_TIRED];
+			allowedBuf[3] = '\0';
 
-			BarUiMsg (MSG_QUESTION, "%s - %s: love[%c] or ban[%c]? ",
+			BarUiMsg (MSG_QUESTION, "%s - %s: love[%c], ban[%c] or tired[%c]? ",
 					selectedSong->artist, selectedSong->title,
 					app->settings.keys[BAR_KS_LOVE],
-					app->settings.keys[BAR_KS_BAN]);
+					app->settings.keys[BAR_KS_BAN],
+					app->settings.keys[BAR_KS_TIRED]);
 			BarReadline (selectBuf, sizeof (selectBuf), allowedBuf, 1, 0, curFd);
 
 			if (selectBuf[0] == app->settings.keys[BAR_KS_LOVE] ||
-					selectBuf[0] == app->settings.keys[BAR_KS_BAN]) {
+					selectBuf[0] == app->settings.keys[BAR_KS_BAN] ||
+					selectBuf[0] == app->settings.keys[BAR_KS_TIRED]) {
 				/* make sure we're transforming the _original_ station (not
 				 * curStation) */
 				PianoStation_t *songStation =
@@ -513,7 +518,8 @@ BarUiActCallback(BarUiActHistory) {
 							&reqData);
 
 					BarUiStartEventCmd (&app->settings, "songlove", songStation,
-							selectedSong, &app->player, pRet, wRet);
+							selectedSong, &app->player, app->ph.stations,
+							pRet, wRet);
 				} else if (selectBuf[0] == app->settings.keys[BAR_KS_BAN]) {
 					PianoRequestDataRateSong_t reqData;
 					reqData.song = selectedSong;
@@ -523,7 +529,15 @@ BarUiActCallback(BarUiActHistory) {
 					BarUiActDefaultPianoCall (PIANO_REQUEST_RATE_SONG,
 							&reqData);
 					BarUiStartEventCmd (&app->settings, "songban", songStation,
-							selectedSong, &app->player, pRet, wRet);
+							selectedSong, &app->player, app->ph.stations,
+							pRet, wRet);
+				} else if (selectBuf[0] == app->settings.keys[BAR_KS_TIRED]) {
+					BarUiMsg (MSG_INFO, "Putting song on shelf... ");
+					BarUiActDefaultPianoCall (PIANO_REQUEST_ADD_TIRED_SONG, selectedSong);
+
+					BarUiStartEventCmd (&app->settings, "songshelf", songStation,
+							selectedSong, &app->player, app->ph.stations,
+							pRet, wRet);
 				} /* end if */
 			} /* end if selectBuf[0] */
 		} /* end if selectedSong != NULL */
@@ -556,3 +570,19 @@ BarUiActCallback(BarUiActBookmark) {
 	}
 }
 
+/*	decrease volume
+ */
+BarUiActCallback(BarUiActVolDown) {
+	--app->settings.volume;
+	/* FIXME: assuming unsigned integer store is atomic operation */
+	app->player.scale = BarPlayerCalcScale (app->player.gain + app->settings.volume);
+}
+
+/*	increase volume
+ */
+BarUiActCallback(BarUiActVolUp) {
+	++app->settings.volume;
+	/* FIXME: assuming unsigned integer store is atomic operation */
+	app->player.scale = BarPlayerCalcScale (app->player.gain + app->settings.volume);
+}
+
